pub struct ModelsConfig {
pub embedding_model: String,
pub ner_model: String,
pub llm_model: String,
pub llm_backend: String,
pub clip_model: String,
pub models_dir: String,
pub enable_ocr: bool,
pub ocr_language: String,
pub tesseract_path: String,
pub fine_tuned_re_model: String,
pub fine_tuned_re_endpoint: String,
pub fine_tuned_re_api_key_env: String,
}Expand description
ML model configuration.
Fields
embedding_model: StringEmbedding model name (default: “all-MiniLM-L6-v2”).
ner_model: StringNER model name (default: “gliner-multi-v2.1”).
llm_model: StringLLM model for relation extraction (default: “Qwen3-4B-GGUF”).
llm_backend: StringLLM backend: “candle” or “llama_cpp” (default: “candle”).
clip_model: StringCLIP model name for image embedding (default: “clip-vit-base-patch32”).
models_dir: StringDirectory for storing model files.
enable_ocr: boolEnable document OCR pipeline (default: true).
ocr_language: StringLanguage for Tesseract OCR (default: “eng”).
tesseract_path: StringPath to the tesseract binary (default: “tesseract”, relies on PATH).
fine_tuned_re_model: StringFine-tuned relation extraction model name on Fireworks (e.g., “accounts/ucotron/models/re-qwen2-5-7b”). When set and non-empty, the extraction pipeline will use this model via Fireworks API instead of co-occurrence. Falls back to co-occurrence on API errors.
fine_tuned_re_endpoint: StringFireworks inference API endpoint (default: “https://api.fireworks.ai/inference/v1”).
fine_tuned_re_api_key_env: StringName of the environment variable holding the Fireworks API key (default: “FIREWORKS_API_KEY”). The actual key is read from this env var at runtime — never stored in config files.